Cookies
=======

Cookies stored by the crawlers can be seen from the :doc:`../admin_ui`, by clicking on ``Cookies``.

.. image:: ../../tests/robotframework/screenshots/cookies_list.png
   :class: sosse-screenshot

You can find which cookie applies to a specific web page by typing its URL in the search bar.
